==> librenms-23.9.1v0.tgz: librenms/app/Http/Controllers/Device/Tabs/LatencyController.php <==
<?php
/**
 * LatencyController.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * @link       https://www.librenms.org
 *
 * @copyright  2020 Tony Murray
 * @author     Tony Murray <murraytony@gmail.com>
 */

namespace App\Http\Controllers\Device\Tabs;

use App\Models\Device;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use LibreNMS\Config;
use LibreNMS\Interfaces\UI\DeviceTab;
use LibreNMS\Util\Smokeping;
use Request;

class LatencyController implements DeviceTab
{
    public function visible(Device $device): bool
    {
        return Config::get('smokeping.integration') || DB::table('device_perf')
            ->where('device_id', $device->device_id)->exists();
    }

    public function slug(): string
    {
        return 'latency';
    }

    public function icon(): string
    {
        return 'fa-line-chart';
    }

    public function name(): string
    {
        return __('Latency');
    }

    public function data(Device $device): array
    {
        $from = Request::get('dtpickerfrom', Carbon::now(session('preferences.timezone'))->subDays(2)->format(Config::get('dateformat.byminute')));
        $to = Request::get('dtpickerto', Carbon::now(session('preferences.timezone'))->format(Config::get('dateformat.byminute')));

        $dbfrom = Carbon::createFromFormat(Config::get('dateformat.byminute'), $from)->setTimezone(date_default_timezone_get())->format(Config::get('dateformat.byminute'));
        $dbto = Carbon::createFromFormat(Config::get('dateformat.byminute'), $to)->setTimezone(date_default_timezone_get())->format(Config::get('dateformat.byminute'));

        $perf = $this->fetchPerfData($device, $dbfrom, $dbto);

        $duration = $perf && $perf->isNotEmpty()
            ? abs(strtotime($perf->first()->date) - strtotime($perf->last()->date)) * 1000
            : 0;

        $smokeping = new Smokeping($device);
        $smokeping_tabs = [];
        if ($smokeping->hasInGraph()) {
            $smokeping_tabs[] = 'in';
        }
        if ($smokeping->hasOutGraph()) {
            $smokeping_tabs[] = 'out';
        }

        return [
            'dtpickerfrom' => $from,
            'dtpickerto' => $to,
            'duration' => $duration,
            'perfdata' => $this->formatPerfData($perf),
            'smokeping' => $smokeping,
            'smokeping_tabs' => $smokeping_tabs,
        ];
    }

    private function fetchPerfData(Device $device, $from, $to)
    {
        return DB::table('device_perf')
            ->where('device_id', $device->device_id)
            ->whereBetween('timestamp', [$from, $to])
            ->selectRaw("DATE_FORMAT(IFNULL(CONVERT_TZ(timestamp, @@global.time_zone, ?), timestamp), '%Y-%m-%d %H:%i') date,xmt,rcv,loss,min,max,avg", [session('preferences.timezone')])
            ->get();
    }

    /**
     * Data ready for json export
     *
     * @param  \Illuminate\Support\Collection  $data
     * @return array
     */
    private function formatPerfData($data)
    {
        return $data->reduce(function ($data, $entry) {
            $data[] = ['x' => $entry->date, 'y' => $entry->loss, 'group' => 0];
            $data[] = ['x' => $entry->date, 'y' => $entry->min, 'group' => 1];
            $data[] = ['x' => $entry->date, 'y' => $entry->max, 'group' => 2];
            $data[] = ['x' => $entry->date, 'y' => $entry->avg, 'group' => 3];

            return $data;
        }, []);
    }
}

==> librenms-25.3.0v0.tgz: librenms/app/Http/Controllers/Device/Tabs/LatencyController.php <==
<?php
/**
 * LatencyController.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * @link       https://www.librenms.org
 *
 * @copyright  2020 Tony Murray
 * @author     Tony Murray <murraytony@gmail.com>
 */

namespace App\Http\Controllers\Device\Tabs;

use App\Models\Device;
use Carbon\Carbon;
use Illuminate\Http\Request;
use LibreNMS\Config;
use LibreNMS\Interfaces\UI\DeviceTab;
use LibreNMS\Util\Smokeping;

class LatencyController implements DeviceTab
{
    public function visible(Device $device): bool
    {
        return Config::get('smokeping.integration') || $device->getAttrib('override_icmp_disable') !== 'true';
    }

    public function slug(): string
    {
        return 'latency';
    }

    public function icon(): string
    {
        return 'fa-line-chart';
    }

    public function name(): string
    {
        return __('Latency');
    }

    public function data(Device $device, Request $request): array
    {
        $from = $request->get('dtpickerfrom', Carbon::now(session('preferences.timezone'))->subDays(2)->format(Config::get('dateformat.byminute')));
        $to = $request->get('dtpickerto', Carbon::now(session('preferences.timezone'))->format(Config::get('dateformat.byminute')));

        $smokeping = new Smokeping($device);
        $smokeping_tabs = [];
        if ($smokeping->hasInGraph()) {
            $smokeping_tabs[] = 'in';
        }
        if ($smokeping->hasOutGraph()) {
            $smokeping_tabs[] = 'out';
        }

        return [
            'from' => $from,
            'to' => $to,
            'smokeping' => $smokeping,
            'smokeping_tabs' => $smokeping_tabs,
        ];
    }
}
